@@ -10,11 +10,11 @@ Usage::
     client: SecretsManagerClient = boto3.client("secretsmanager")
     ```
 """
-import sys
 from typing import IO, Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_secretsmanager.literals import ListSecretsPaginatorName, SortOrderType
 from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
 from mypy_boto3_secretsmanager.type_defs import (
     CancelRotateSecretResponseTypeDef,
@@ -43,12 +43,6 @@ from mypy_boto3_secretsmanager.type_defs import (
     ValidateResourcePolicyResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("SecretsManagerClient",)
 
 
@@ -184,7 +178,7 @@ class SecretsManagerClient:
         MaxResults: int = None,
         NextToken: str = None,
         Filters: List[FilterTypeDef] = None,
-        SortOrder: Literal["asc", "desc"] = None,
+        SortOrder: SortOrderType = None,
     ) -> ListSecretsResponseTypeDef:
         """
         [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
@@ -288,7 +282,7 @@ class SecretsManagerClient:
         [Client.validate_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
         """
 
-    def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
+    def get_paginator(self, operation_name: ListSecretsPaginatorName) -> ListSecretsPaginator:
         """
         [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
         """
