@@ -16,23 +16,17 @@ Usage::
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
     ```
 """
-import sys
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_secretsmanager.literals import SortOrderType
 from mypy_boto3_secretsmanager.type_defs import (
     FilterTypeDef,
     ListSecretsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("ListSecretsPaginator",)
 
 
@@ -44,7 +38,7 @@ class ListSecretsPaginator(Boto3Paginator):
     def paginate(
         self,
         Filters: List[FilterTypeDef] = None,
-        SortOrder: Literal["asc", "desc"] = None,
+        SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSecretsResponseTypeDef]:
         """
